@@ -13,18 +13,13 @@ between grid points. The `quantecon.ivp` module also provides a method
 for computing the residual of the solution which can be used for
 assessing the overall accuracy of the approximated solution.
 
-@author : David R. Pugh
-@date : 2014-09-09
-
 """
-from __future__ import division
-
 import numpy as np
 from scipy import integrate, interpolate
 
 
 class IVP(integrate.ode):
-    
+
     r"""
     Creates an instance of the IVP class.
 
