@@ -146,7 +146,8 @@ class RBLQ:
         S1 = Q + beta * dot(B.T, dot(P, B))
         S2 = beta * dot(B.T, dot(P, A))
         S3 = beta * dot(A.T, dot(P, A))
-        F = solve(S1, S2) if not self.pure_forecasting else np.zeros((self.k, self.n))
+        F = solve(S1, S2) if not self.pure_forecasting else np.zeros(
+            (self.k, self.n))
         new_P = R - dot(S2.T, F) + S3
 
         return F, new_P
